@@ -431,7 +431,7 @@ class AdvancedFeaturesTests(unittest.TestCase):
     @unittest.skipIf(not url_support or not responses, 'validators, requests and responses packages are required')
     @responses_activate
     def test_urls(self):
-        set_url_support(True)
+        set_config_read_mode(urls_enabled=True)
         parser = ArgumentParser()
         parser.add_argument('--cfg',
             action=ActionConfigFile)
@@ -492,7 +492,7 @@ class AdvancedFeaturesTests(unittest.TestCase):
         if jsonnet_support:
             self.assertEqual(cfg1['jsonnet'], cfg2['jsonnet'])
 
-        set_url_support(False)
+        set_config_read_mode(urls_enabled=False)
 
 
 class OutputTests(TempDirTestCase):
@@ -691,7 +691,8 @@ class OutputTests(TempDirTestCase):
 
 
     def test_print_config(self):
-        parser = ArgumentParser(error_handler=None)
+        parser = ArgumentParser(error_handler=None, description='cli tool')
+        parser.add_argument('--cfg', action=ActionConfigFile)
         parser.add_argument('--v0', help=SUPPRESS, default='0')
         parser.add_argument('--v1', help='Option v1.', default=1)
         parser.add_argument('--g1.v2', help='Option v2.', default='2')
@@ -709,12 +710,19 @@ class OutputTests(TempDirTestCase):
         out = StringIO()
         with redirect_stdout(out), self.assertRaises(SystemExit):
             parser.parse_args(['--print_config=skip_null'])
-
         outval = yaml.safe_load(out.getvalue())
         self.assertEqual(outval, {'g1': {'v2': '2'}, 'v1': 1})
 
         self.assertRaises(ParserError, lambda: parser.parse_args(['--print_config=bad']))
 
+        if docstring_parser_support and ruyaml_support:
+            out = StringIO()
+            with redirect_stdout(out), self.assertRaises(SystemExit):
+                parser.parse_args(['--print_config=comments'])
+            self.assertIn('# cli tool', out.getvalue())
+            self.assertIn('# Option v1. (default: 1)', out.getvalue())
+            self.assertIn('# Option v2. (default: 2)', out.getvalue())
+
 
 class ConfigFilesTests(TempDirTestCase):
 
